@@ -27,9 +27,9 @@ enum {
 };
 
 static char *marker_files[MARKER_NB] = {
-        ICONDIR "/clock-map-location-marker.png",
-        ICONDIR "/clock-map-location-hilight.png",
-        ICONDIR "/clock-map-location-current.png"
+        "clock-map-location-marker.png",
+        "clock-map-location-hilight.png",
+        "clock-map-location-current.png"
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -135,8 +135,11 @@ clock_map_init (ClockMap *this)
         g_assert (sizeof (marker_files)/sizeof (char *) == MARKER_NB);
 
         for (i = 0; i < MARKER_NB; i++) {
-                priv->location_marker_pixbuf[i] = gdk_pixbuf_new_from_file
-                                                  (marker_files[i], NULL);
+                char *resource;
+
+                resource = g_strconcat (CLOCK_RESOURCE_PATH "icons/", marker_files[i], NULL);
+                priv->location_marker_pixbuf[i] = gdk_pixbuf_new_from_resource (resource, NULL);
+                g_free (resource);
         }
 }
 
@@ -208,11 +211,10 @@ clock_map_refresh (ClockMap *this)
         }
 
         if (!priv->stock_map_pixbuf) {
-                GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale
-                        (ICONDIR "/clock-map.png",
-                         priv->width, priv->height, FALSE, NULL);
-
-                priv->stock_map_pixbuf = pixbuf;
+                priv->stock_map_pixbuf = gdk_pixbuf_new_from_resource_at_scale (CLOCK_RESOURCE_PATH "icons/clock-map.png",
+                                                                                priv->width, priv->height,
+                                                                                FALSE,
+                                                                                NULL);
         }
 
         clock_map_place_locations (this);
