@@ -256,7 +256,7 @@ update (SnItemV0 *v0)
       if (!pixbuf){
           /*try to find icons specified by path and filename*/
           pixbuf = gdk_pixbuf_new_from_file(v0->icon_name, NULL);
-          if (pixbuf){
+          if (pixbuf && icon_size > 1) {
               /*An icon specified by path and filename may be the wrong size for the tray */
               pixbuf=gdk_pixbuf_scale_simple(pixbuf, icon_size-2, icon_size-2,GDK_INTERP_BILINEAR);
           }
