@@ -13,7 +13,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
@@ -103,7 +103,7 @@ get_tray (TraysScreen *trays_screen)
 {
   if (trays_screen->all_trays == NULL)
     return NULL;
-  
+
   return trays_screen->all_trays->data;
 }
 
@@ -127,7 +127,8 @@ tray_added (NaTrayManager *manager,
 
   na_host_emit_item_added (NA_HOST (tray), NA_ITEM (icon));
 
-  gtk_widget_show (GTK_WIDGET (icon));
+  /*Does not seem to be needed anymore and can cause a render issue with hidpi*/
+  /*gtk_widget_show (GTK_WIDGET (icon));*/
 }
 
 static void
@@ -282,7 +283,7 @@ message_sent (NaTrayManager *manager,
   icontip = g_hash_table_lookup (trays_screen->tip_table, icon);
 
   find_buffer.id = id;
-  if (icontip && 
+  if (icontip &&
       (icontip->id == id ||
        g_slist_find_custom (icontip->buffer, &find_buffer,
                             icon_tip_buffer_compare) != NULL))
@@ -437,7 +438,7 @@ na_tray_constructor (GType type,
       initialized = TRUE;
     }
 
-  screen_number = gdk_screen_get_number (priv->screen);
+  screen_number = gdk_x11_screen_get_screen_number (priv->screen);
 
   if (trays_screens [screen_number].tray_manager == NULL)
     {
@@ -477,7 +478,7 @@ na_tray_constructor (GType type,
           g_object_unref (tray_manager);
         }
     }
-      
+
   priv->trays_screen = &trays_screens [screen_number];
   trays_screens [screen_number].all_trays = g_slist_append (trays_screens [screen_number].all_trays,
                                                             tray);
@@ -711,7 +712,7 @@ idle_redraw_cb (NaTray *tray)
 
   g_hash_table_foreach (priv->trays_screen->icon_table,
                         (GHFunc) na_tray_child_force_redraw, NULL);
-  
+
   priv->idle_redraw_id = 0;
 
   return FALSE;
