@@ -42,6 +42,9 @@ typedef struct {
 
 	GtkOrientation orientation;
 	int size;
+#if !defined(WNCKLET_INPROCESS) && !GTK_CHECK_VERSION (3, 23, 0)
+	gboolean needs_hints;
+#endif
 
 	GtkIconTheme* icon_theme;
 
@@ -319,7 +322,27 @@ static void applet_size_allocate(GtkWidget *widget, GtkAllocation *allocation, T
 
 	g_assert(len % 2 == 0);
 
-	mate_panel_applet_set_size_hints(MATE_PANEL_APPLET(tasklist->applet), size_hints, len, 0);
+#if !defined(WNCKLET_INPROCESS) && !GTK_CHECK_VERSION (3, 23, 0)
+	/* HACK: When loading the WnckTasklist initially, it reports size hints as though there were
+	 * no elements in the Tasklist. This causes a rendering issue when built out-of-process in
+	 * HiDPI displays. We keep a flag to skip size hinting until WnckTasklist has something to
+	 * show. */
+	if (!tasklist->needs_hints)
+	{
+		int i;
+		for (i = 0; i < len; i++)
+		{
+			if (size_hints[i])
+			{
+				tasklist->needs_hints = TRUE;
+				break;
+			}
+		}
+	}
+
+	if (tasklist->needs_hints)
+#endif
+		mate_panel_applet_set_size_hints(MATE_PANEL_APPLET(tasklist->applet), size_hints, len, 0);
 }
 
 static GdkPixbuf* icon_loader_func(const char* icon, int size, unsigned int flags, void* data)
@@ -372,7 +395,6 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 {
 	TasklistData* tasklist;
 	GtkActionGroup* action_group;
-	gchar* ui_path;
 	GtkCssProvider  *provider;
 	GdkScreen *screen;
 
@@ -405,6 +427,10 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 	tasklist->size = mate_panel_applet_get_size(applet);
 
+#if !defined(WNCKLET_INPROCESS) && !GTK_CHECK_VERSION (3, 23, 0)
+	tasklist->needs_hints = FALSE;
+#endif
+
 	switch (mate_panel_applet_get_orient(applet))
 	{
 		case MATE_PANEL_APPLET_ORIENT_LEFT:
@@ -468,9 +494,9 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	/* end of system monitor item */
 	
 
-	ui_path = g_build_filename(WNCK_MENU_UI_DIR, "window-list-menu.xml", NULL);
-	mate_panel_applet_setup_menu_from_file(MATE_PANEL_APPLET(tasklist->applet), ui_path, action_group);
-	g_free(ui_path);
+	mate_panel_applet_setup_menu_from_resource (MATE_PANEL_APPLET (tasklist->applet),
+	                                            WNCKLET_RESOURCE_PATH "window-list-menu.xml",
+	                                            action_group);
 
 	if (mate_panel_applet_get_locked_down(MATE_PANEL_APPLET(tasklist->applet)))
 	{
@@ -649,20 +675,10 @@ static void display_properties_dialog(GtkAction* action, TasklistData* tasklist)
 	if (tasklist->properties_dialog == NULL)
 	{
 		GtkBuilder* builder;
-		GError* error;
 
 		builder = gtk_builder_new();
 		gtk_builder_set_translation_domain(builder, GETTEXT_PACKAGE);
-
-		error = NULL;
-		gtk_builder_add_from_file(builder, TASKLIST_BUILDERDIR "/window-list.ui", &error);
-
-		if (error)
-		{
-			g_warning("Error loading preferences: %s", error->message);
-			g_error_free(error);
-			return;
-		}
+		gtk_builder_add_from_resource (builder, WNCKLET_RESOURCE_PATH "window-list.ui", NULL);
 
 		tasklist->properties_dialog = WID("tasklist_properties_dialog");
 
