@@ -120,7 +120,8 @@ static void update_properties_for_wm(PagerData* pager)
 				gtk_widget_show(pager->workspace_names_scroll);
 			if (pager->display_workspaces_toggle)
 				gtk_widget_show(pager->display_workspaces_toggle);
-			g_object_set (pager->cell, "editable", TRUE, NULL);
+			if (pager->cell)
+				g_object_set (pager->cell, "editable", TRUE, NULL);
 			break;
 		case PAGER_WM_METACITY:
 			if (pager->workspaces_frame)
@@ -131,7 +132,8 @@ static void update_properties_for_wm(PagerData* pager)
 				gtk_widget_show(pager->workspace_names_scroll);
 			if (pager->display_workspaces_toggle)
 				gtk_widget_show(pager->display_workspaces_toggle);
-			g_object_set (pager->cell, "editable", TRUE, NULL);
+			if (pager->cell)
+				g_object_set (pager->cell, "editable", TRUE, NULL);
 			break;
 		case PAGER_WM_I3:
 			if (pager->workspaces_frame)
@@ -144,7 +146,8 @@ static void update_properties_for_wm(PagerData* pager)
 				gtk_widget_hide(pager->workspace_names_scroll);
 			if (pager->display_workspaces_toggle)
 				gtk_widget_show(pager->display_workspaces_toggle);
-			g_object_set (pager->cell, "editable", FALSE, NULL);
+			if (pager->cell)
+				g_object_set (pager->cell, "editable", FALSE, NULL);
 			break;
 		case PAGER_WM_COMPIZ:
 			if (pager->workspaces_frame)
@@ -155,7 +158,8 @@ static void update_properties_for_wm(PagerData* pager)
 				gtk_widget_hide(pager->workspace_names_scroll);
 			if (pager->display_workspaces_toggle)
 				gtk_widget_hide(pager->display_workspaces_toggle);
-			g_object_set (pager->cell, "editable", FALSE, NULL);
+			if (pager->cell)
+				g_object_set (pager->cell, "editable", FALSE, NULL);
 			break;
 		case PAGER_WM_UNKNOWN:
 			if (pager->workspaces_frame)
@@ -492,7 +496,6 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 {
 	PagerData* pager;
 	GtkActionGroup* action_group;
-	gchar* ui_path;
 	gboolean display_names;
 	GtkCssProvider *provider;
 
@@ -577,9 +580,9 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 	action_group = gtk_action_group_new("WorkspaceSwitcher Applet Actions");
 	gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions(action_group, pager_menu_actions, G_N_ELEMENTS(pager_menu_actions), pager);
-	ui_path = g_build_filename(WNCK_MENU_UI_DIR, "workspace-switcher-menu.xml", NULL);
-	mate_panel_applet_setup_menu_from_file(MATE_PANEL_APPLET(pager->applet), ui_path, action_group);
-	g_free(ui_path);
+	mate_panel_applet_setup_menu_from_resource (MATE_PANEL_APPLET (pager->applet),
+	                                            WNCKLET_RESOURCE_PATH "workspace-switcher-menu.xml",
+	                                            action_group);
 
 	if (mate_panel_applet_get_locked_down(MATE_PANEL_APPLET(pager->applet)))
 	{
@@ -968,20 +971,10 @@ static void display_properties_dialog(GtkAction* action, PagerData* pager)
 	if (pager->properties_dialog == NULL)
 	{
 		GtkBuilder* builder;
-		GError* error;
 
 		builder = gtk_builder_new();
 		gtk_builder_set_translation_domain(builder, GETTEXT_PACKAGE);
-
-		error = NULL;
-		gtk_builder_add_from_file(builder, PAGER_BUILDERDIR "/workspace-switcher.ui", &error);
-
-		if (error)
-		{
-			g_warning("Error loading preferences: %s", error->message);
-			g_error_free(error);
-			return;
-		}
+		gtk_builder_add_from_resource (builder, WNCKLET_RESOURCE_PATH "workspace-switcher.ui", NULL);
 
 		pager->properties_dialog = WID("pager_properties_dialog");
 
