@@ -40,16 +40,12 @@ typedef struct _MatePanelAppletFactoryClass   MatePanelAppletFactoryClass;
 
 GType               mate_panel_applet_factory_get_type         (void) G_GNUC_CONST;
 MatePanelAppletFactory *mate_panel_applet_factory_new              (const gchar        *applet_id,
+								gboolean            out_of_process,
 							   GType               applet_type,
 							   GClosure           *closure);
 gboolean            mate_panel_applet_factory_register_service (MatePanelAppletFactory *factory);
-
-/* This technically belongs to mate-panel-applet.h, but it's not something that
- * should be public API. */
-guint32            mate_panel_applet_get_xid              (MatePanelApplet *applet,
-						      GdkScreen   *screen);
-const gchar       *mate_panel_applet_get_object_path      (MatePanelApplet *applet);
-
+GtkWidget          *mate_panel_applet_factory_get_applet_widget (const gchar        *id,
+                                                            guint               uid);
 #ifdef __cplusplus
 }
 #endif
