@@ -711,6 +711,46 @@ mate_panel_applet_setup_menu_from_file (MatePanelApplet    *applet,
 	g_free (xml);
 }
 
+/**
+ * mate_panel_applet_setup_menu_from_resource:
+ * @applet: a #MatePanelApplet.
+ * @resource_path: a resource path
+ * @action_group: a #GtkActionGroup.
+ *
+ * Sets up the context menu of @applet. @filename is a resource path to a menu
+ * XML file, containing a #GtkUIManager UI definition that describes how to
+ * display the menu items. @action_group contains the various #GtkAction that
+ * are referenced in @xml.
+ *
+ * See also the <link linkend="getting-started.context-menu">Context
+ * Menu</link> section.
+ *
+ * Since: 1.20.1
+ **/
+void
+mate_panel_applet_setup_menu_from_resource (MatePanelApplet    *applet,
+				       const gchar    *resource_path,
+				       GtkActionGroup *action_group)
+{
+	GBytes *bytes;
+	GError *error = NULL;
+
+	bytes = g_resources_lookup_data (resource_path,
+					 G_RESOURCE_LOOKUP_FLAGS_NONE,
+					 &error);
+
+	if (bytes) {
+		mate_panel_applet_setup_menu (applet,
+					 g_bytes_get_data (bytes, NULL),
+					 action_group);
+	} else {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+	}
+
+	g_bytes_unref (bytes);
+}
+
 static void
 mate_panel_applet_finalize (GObject *object)
 {
@@ -1014,21 +1054,23 @@ mate_panel_applet_get_preferred_width (GtkWidget *widget,
 				       int       *minimum_width,
 				       int       *natural_width)
 {
-	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
-	gint scale;
-
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_width (widget,
 										minimum_width,
 										natural_width);
 
+#if !GTK_CHECK_VERSION (3, 23, 0)
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
 	if (applet->priv->out_of_process) {
-		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
+		/* Out-of-process applets end up scaled up doubly with GTK 3.22.
+		 * For these builds divide by the scale factor to ensure
 		 * they are back at their own intended size.
 		 */
+		gint scale;
 		scale = gtk_widget_get_scale_factor (widget);
 		*minimum_width /= scale;
 		*natural_width /= scale;
 	}
+#endif
 }
 
 static void
@@ -1036,38 +1078,37 @@ mate_panel_applet_get_preferred_height (GtkWidget *widget,
 					int       *minimum_height,
 					int       *natural_height)
 {
-	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
-	gint scale;
-
 	GTK_WIDGET_CLASS (mate_panel_applet_parent_class)->get_preferred_height (widget,
 										minimum_height,
 										natural_height);
 
+#if !GTK_CHECK_VERSION (3, 23, 0)
+	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
 	if (applet->priv->out_of_process) {
-		/* Out-of-process applets end up scaled up doubly. We divide by the scale factor to ensure
+		gint scale;
+		/* Out-of-process applets end up scaled up doubly with GTK 3.22.
+		 * For these builds divide by the scale factor to ensure
 		 * they are back at their own intended size.
 		 */
 		scale = gtk_widget_get_scale_factor (widget);
 		*minimum_height /= scale;
 		*natural_height /= scale;
 	}
+#endif
 }
 
 static GtkSizeRequestMode
 mate_panel_applet_get_request_mode (GtkWidget *widget)
 {
-	MatePanelApplet *applet = MATE_PANEL_APPLET (widget);
-	MatePanelAppletOrient orientation;
-
-	if (applet->priv->out_of_process)
-		return GTK_SIZE_REQUEST_CONSTANT_SIZE;
-
-	orientation = mate_panel_applet_get_orient (applet);
-	if (orientation == MATE_PANEL_APPLET_ORIENT_UP ||
-	    orientation == MATE_PANEL_APPLET_ORIENT_DOWN)
-		return GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH;
-
-	return GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT;
+	/*Do not use GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH
+	 *or GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT
+	 *to avoid problems with in-process applets
+	 *when the panel is not expanded
+	 *See https://github.com/mate-desktop/mate-panel/issues/797
+	 *and https://github.com/mate-desktop/mate-panel/issues/799
+	 *Out of process applets already use GTK_SIZE_REQUEST_CONSTANT_SIZE
+	 */
+	return GTK_SIZE_REQUEST_CONSTANT_SIZE;
 }
 
 static void
@@ -2259,10 +2300,12 @@ _mate_panel_applet_factory_main_internal (const gchar               *factory_id,
 	g_return_val_if_fail(callback != NULL, 1);
 	g_assert(g_type_is_a(applet_type, PANEL_TYPE_APPLET));
 
-	if (out_process)
-	{
-		_mate_panel_applet_setup_x_error_handler();
-	}
+	/*Use this both in and out of process as the tray applet always uses GtkSocket
+	 *to handle GtkStatusIcons whether the tray itself is built in or out of process
+     */
+
+	_mate_panel_applet_setup_x_error_handler();
+
 
 	closure = g_cclosure_new(G_CALLBACK(callback), user_data, NULL);
 	factory = mate_panel_applet_factory_new(factory_id, out_process,  applet_type, closure);
