@@ -641,8 +641,6 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 	int             menu_y = 0;
 	int             pointer_x;
 	int             pointer_y;
-	int             screen_width;
-	int             screen_height;
 
 	parent = gtk_widget_get_parent (applet);
 
@@ -653,13 +651,10 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
 
 	gdk_window_get_origin (gtk_widget_get_window (applet), &menu_x, &menu_y);
-#if GTK_CHECK_VERSION(3, 20, 0)
+
 	device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (applet)));
 	gdk_window_get_device_position (gtk_widget_get_window (applet), device, &pointer_x, &pointer_y, NULL);
-#else
-	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (applet)));
-	gdk_window_get_device_position (gtk_widget_get_window (applet), device, &pointer_x, &pointer_y, NULL);
-#endif
+
 	gtk_widget_get_allocation (applet, &allocation);
 
 	if (!gtk_widget_get_has_window (applet)) {
@@ -667,9 +662,6 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 		menu_y += allocation.y;
 	}
 
-	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-				 &screen_width, &screen_height);
-
 	if (PANEL_WIDGET (parent)->orient == GTK_ORIENTATION_HORIZONTAL) {
 		if (gtk_widget_get_direction (GTK_WIDGET (menu)) != GTK_TEXT_DIR_RTL) {
 			if (pointer_x < allocation.width &&
@@ -684,9 +676,9 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 					       allocation.width - requisition.width);
 			}
 		}
-		menu_x = MIN (menu_x, screen_width - requisition.width);
+		menu_x = MIN (menu_x, WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) - requisition.width);
 
-		if (menu_y > screen_height / 2)
+		if (menu_y > HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / 2)
 			menu_y -= requisition.height;
 		else
 			menu_y += allocation.height;
@@ -694,9 +686,9 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 		if (pointer_y < allocation.height &&
 		    requisition.height < pointer_y)
 			menu_y += MIN (pointer_y, allocation.height - requisition.height);
-		menu_y = MIN (menu_y, screen_height - requisition.height);
+		menu_y = MIN (menu_y, HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) - requisition.height);
 
-		if (menu_x > screen_width / 2)
+		if (menu_x > WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / 2)
 			menu_x -= requisition.width;
 		else
 			menu_x += allocation.width;
@@ -796,6 +788,8 @@ mate_panel_applet_destroy (GtkWidget  *widget,
 {
 	g_return_if_fail (info != NULL);
 
+	g_signal_handlers_disconnect_by_data(info->settings,widget);
+
 	info->widget = NULL;
 
 	if (info->settings) {
