@@ -55,12 +55,26 @@ static const GOptionEntry options[] = {
   { NULL }
 };
 
+static void
+parsing_error_cb (GtkCssProvider *provider,
+                  GtkCssSection  *section,
+                  GError         *error,
+                  gpointer        user_data)
+{
+    g_warning ("Can't parse mate-panel's CSS custom description: %s\n", error->message);
+}
+
 int
 main (int argc, char **argv)
 {
 	char           *desktopfile;
 	GOptionContext *context;
 	GError         *error;
+	GdkScreen      *screen;
+	GtkCssProvider *css;
+	GtkStyleProvider *provider;
+	const gchar    *resource;
+	guint          priority;
 
 	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -85,9 +99,6 @@ main (int argc, char **argv)
 
 	gtk_init (&argc, &argv);
 
-    /* FIXME: High dpi scaling does not work... */
-    gdk_x11_display_set_window_scale (gdk_display_get_default (), 1);
-
 	error = NULL;
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
 		g_printerr ("%s\n", error->message);
@@ -169,6 +180,20 @@ main (int argc, char **argv)
 	 * connecting to the session manager */
 	panel_session_init ();
 
+	/*Load a css file from a GResource so the drag handle image can be loaded*/
+	screen = gdk_screen_get_default ();
+	css = gtk_css_provider_new ();
+	provider = GTK_STYLE_PROVIDER (css);
+	resource = "/org/mate/panel/theme/mate-panel.css";
+	priority = GTK_STYLE_PROVIDER_PRIORITY_FALLBACK;
+
+	g_signal_connect (provider, "parsing-error", G_CALLBACK (parsing_error_cb), NULL);
+
+	gtk_css_provider_load_from_resource (css, resource);
+	gtk_style_context_add_provider_for_screen (screen, provider, priority);
+
+	g_object_unref (provider);
+
 	gtk_main ();
 
 	panel_lockdown_finalize ();
