@@ -47,6 +47,7 @@
 #include "panel-lockdown.h"
 #include "panel-addto.h"
 #include "panel-icon-names.h"
+#include "panel-reset.h"
 
 static void
 panel_context_menu_show_help (GtkWidget *w,
@@ -86,7 +87,7 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 		"Stephen Browne <stephen.browne@sun.com>",
 		"Tom Tromey <tromey@cygnus.com>",
 		"Vincent Untz <vuntz@gnome.org>",
-		N_("And many, many others..."),
+		N_("And many, many others…"),
 		NULL
 	};
 	char *documenters[] = {
@@ -112,7 +113,7 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 		      "program-name",  _("The MATE Panel"),
 		      "version", VERSION,
 		      "copyright", "Copyright \xc2\xa9 1997-2003 Free Software Foundation, Inc.\n"
-		                   "Copyright \xc2\xa9 2011-2017 MATE Developers.",
+		                   "Copyright \xc2\xa9 2011-2018 MATE Developers.",
 		      "comments", _("This program is responsible for launching other "
 				    "applications and provides useful utilities."),
 		      "authors", authors,
@@ -175,6 +176,53 @@ panel_context_menu_setup_delete_panel_item (GtkWidget *menu,
 	gtk_widget_set_sensitive (menuitem, sensitive);
 }
 
+static void
+panel_reset_response (GtkWidget     *dialog,
+			 int            response)
+{
+	if (response == GTK_RESPONSE_OK) {
+		panel_reset ();
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
+static void
+query_panel_reset (PanelToplevel *toplevel)
+{
+	GtkWidget *dialog;
+	char *text1;
+	char *text2;
+
+	text1 = _("Reset this panel?");
+	text2 = _("When a panel is reset, all \n"
+			 "custom settings are lost.");
+
+	dialog = gtk_message_dialog_new (
+			GTK_WINDOW (toplevel),
+			GTK_DIALOG_MODAL,
+			GTK_MESSAGE_WARNING,
+			GTK_BUTTONS_NONE,
+			"%s", text1);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+	                                          "%s", text2);
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				_("_Cancel"), GTK_RESPONSE_CANCEL,
+				_("_Reset Panel"), GTK_RESPONSE_OK,
+				NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (panel_reset_response),
+			  NULL);
+
+	gtk_widget_show_all (dialog);
+}
+
 static void
 panel_context_menu_build_edition (PanelWidget *panel_widget,
 				  GtkWidget   *menu)
@@ -182,7 +230,7 @@ panel_context_menu_build_edition (PanelWidget *panel_widget,
 	GtkWidget *menuitem;
 	GtkWidget *image;
 
-	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Add to Panel..."));
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Add to Panel…"));
 	image = gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	gtk_widget_show (menuitem);
@@ -203,6 +251,16 @@ panel_context_menu_build_edition (PanelWidget *panel_widget,
 				  G_CALLBACK (panel_properties_dialog_present), 
 				  panel_widget->toplevel);
 
+	add_menu_separator (menu);
+
+	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Reset Panel"));
+	image = gtk_image_new_from_icon_name ("document-revert", GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_widget_show (menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect_swapped (menuitem, "activate",
+			  G_CALLBACK (query_panel_reset), panel_widget->toplevel);
+
 	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Delete This Panel"));
 	image = gtk_image_new_from_icon_name ("edit-delete",
 					      GTK_ICON_SIZE_MENU);
