@@ -65,23 +65,15 @@ display_popup_window (GdkScreen *screen)
 	gtk_container_add (GTK_CONTAINER (retval), frame);
 	gtk_widget_show (frame);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-	vbox = gtk_vbox_new (FALSE, 0);
-#endif
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 	gtk_widget_show (vbox);
 
 	image = gtk_image_new_from_icon_name (PANEL_ICON_FORCE_QUIT,
 					      GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
 	gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
-#else
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.5);
-#endif
 	gtk_box_pack_start (GTK_BOX (vbox), image, TRUE, TRUE, 4);
 	gtk_widget_show (image);
 
@@ -94,8 +86,8 @@ display_popup_window (GdkScreen *screen)
 
 	gtk_widget_realize (retval);
 
-	screen_width  = gdk_screen_get_width  (screen);
-	screen_height = gdk_screen_get_height (screen);
+	screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
+	screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
 
 	gtk_widget_get_allocation (retval, &allocation);
 
@@ -112,16 +104,8 @@ static void
 remove_popup (GtkWidget *popup)
 {
 	GdkWindow        *root;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkDisplay       *display;
-#if GTK_CHECK_VERSION (3, 20, 0)
 	GdkSeat          *seat;
-#else
-	GdkDevice        *pointer;
-	GdkDevice        *keyboard;
-	GdkDeviceManager *device_manager;
-#endif
-#endif
 
 	root = gdk_screen_get_root_window (
 			gtk_window_get_screen (GTK_WINDOW (popup)));
@@ -129,24 +113,10 @@ remove_popup (GtkWidget *popup)
 
 	gtk_widget_destroy (popup);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display = gdk_window_get_display (root);
-#if GTK_CHECK_VERSION (3, 20, 0)
 	seat = gdk_display_get_default_seat (display);
 
 	gdk_seat_ungrab (seat);
-#else
-	device_manager = gdk_display_get_device_manager (display);
-	pointer = gdk_device_manager_get_client_pointer (device_manager);
-	keyboard = gdk_device_get_associated_device (pointer);
-
-	gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-	gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
-#endif
-#else
-	gdk_pointer_ungrab (GDK_CURRENT_TIME);
-	gdk_keyboard_ungrab (GDK_CURRENT_TIME);
-#endif
 }
 
 static gboolean
@@ -232,11 +202,7 @@ kill_window_response (GtkDialog *dialog,
 		gdk_error_trap_push ();
 		XKillClient (display, window);
 		gdk_flush ();
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_error_trap_pop_ignored ();
-#else
-		gdk_error_trap_pop ();
-#endif
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -259,7 +225,7 @@ kill_window_question (gpointer window)
 						  "in it might get lost."));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_CANCEL,
+				"gtk-cancel",
 				GTK_RESPONSE_CANCEL,
 				PANEL_STOCK_FORCE_QUIT,
 				GTK_RESPONSE_ACCEPT,
@@ -348,16 +314,10 @@ panel_force_quit (GdkScreen *screen,
 	GdkCursor     *cross;
 	GtkWidget     *popup;
 	GdkWindow     *root;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkDisplay    *display;
 	GdkDevice     *pointer;
 	GdkDevice     *keyboard;
-#if GTK_CHECK_VERSION (3, 20, 0)
 	GdkSeat       *seat;
-#else
-	GdkDeviceManager *device_manager;
-#endif
-#endif
 
 	popup = display_popup_window (screen);
 
@@ -366,15 +326,9 @@ panel_force_quit (GdkScreen *screen,
 	gdk_window_add_filter (root, (GdkFilterFunc) popup_filter, popup);
 	cross = gdk_cursor_new_for_display (gdk_display_get_default (),
 	                                    GDK_CROSS);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display = gdk_window_get_display (root);
-#if GTK_CHECK_VERSION (3, 20, 0)
 	seat = gdk_display_get_default_seat (display);
 	pointer = gdk_seat_get_pointer (seat);
-#else
-	device_manager = gdk_display_get_device_manager (display);
-	pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
 	keyboard = gdk_device_get_associated_device (pointer);
 
 	status = gdk_device_grab (pointer, root,
@@ -394,24 +348,6 @@ panel_force_quit (GdkScreen *screen,
 		remove_popup (popup);
 		return;
 	}
-#else
-	status = gdk_pointer_grab (root, FALSE, GDK_BUTTON_PRESS_MASK,
-				   NULL, cross, time);
 
-	gdk_cursor_unref (cross);
-
-	if (status != GDK_GRAB_SUCCESS) {
-		g_warning ("Pointer grab failed\n");
-		remove_popup (popup);
-		return;
-	}
-
-	status = gdk_keyboard_grab (root, FALSE, time);
-	if (status != GDK_GRAB_SUCCESS) {
-		g_warning ("Keyboard grab failed\n");
-		remove_popup (popup);
-		return;
-	}
-#endif
 	gdk_flush ();
 }
