@@ -28,6 +28,9 @@
 
 #include "panel-menu-bar.h"
 
+#include <X11/Xlib.h>
+#include <gdk/gdkx.h>
+
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -65,6 +68,8 @@ struct _PanelMenuBarPrivate {
 	GSettings* settings;
 
 	PanelOrientation orientation;
+
+	Window interrupted_window;
 };
 
 enum {
@@ -83,6 +88,15 @@ static gboolean panel_menu_bar_reinit_tooltip(GtkWidget* widget, PanelMenuBar* m
 	return FALSE;
 }
 
+static gboolean panel_menu_bar_deactivate (GtkWidget* widget, PanelMenuBar* menubar)
+{
+	GtkWidget *toplevel = gtk_widget_get_toplevel (widget);
+	panel_util_set_current_active_window (toplevel, menubar->priv->interrupted_window);
+	menubar->priv->interrupted_window = None;
+
+	return FALSE;
+}
+
 static gboolean panel_menu_bar_hide_tooltip_and_focus(GtkWidget* widget, PanelMenuBar* menubar)
 {
 	/* remove focus that would be drawn on the currently focused child of
@@ -108,6 +122,7 @@ static void panel_menu_bar_setup_tooltip(PanelMenuBar* menubar)
 
 	/* Reset tooltip when the menu bar is not used */
 	g_signal_connect(GTK_MENU_SHELL (menubar), "deactivate", G_CALLBACK (panel_menu_bar_reinit_tooltip), menubar);
+	g_signal_connect(GTK_MENU_SHELL (menubar), "deactivate", G_CALLBACK (panel_menu_bar_deactivate), menubar);
 }
 
 static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, PanelMenuBar* menubar)
@@ -411,11 +426,18 @@ void panel_menu_bar_popup_menu(PanelMenuBar* menubar, guint32 activate_time)
 {
 	GtkMenu* menu;
 	GtkMenuShell* menu_shell;
+	GtkWidget* toplevel;
+	GdkWindow* window;
 
 	g_return_if_fail(PANEL_IS_MENU_BAR(menubar));
 
 	menu = GTK_MENU(menubar->priv->applications_menu);
 
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (menubar));
+	menubar->priv->interrupted_window = panel_util_get_current_active_window (toplevel);
+	window = gtk_widget_get_window (toplevel);
+	panel_util_set_current_active_window (toplevel, GDK_WINDOW_XID(window));
+
 	/*
 	 * We need to call _gtk_menu_shell_activate() here as is done in
 	 * window_key_press_handler in gtkmenubar.c which pops up menu
