@@ -55,6 +55,7 @@
 #include "panel-globals.h"
 #include "panel-enums.h"
 #include "panel-profile.h"
+#include "panel-schemas.h"
 #include "panel-stock-icons.h"
 #include "panel-multiscreen.h"
 #include "menu.h"
@@ -2011,7 +2012,6 @@ panel_run_dialog_present (GdkScreen *screen,
 			  guint32    activate_time)
 {
 	GtkBuilder *gui;
-	GError     *error;
 
 	if (panel_lockdown_get_disable_command_line ())
 		return;
@@ -2026,28 +2026,9 @@ panel_run_dialog_present (GdkScreen *screen,
 
 	gui = gtk_builder_new ();
 	gtk_builder_set_translation_domain (gui, GETTEXT_PACKAGE);
-
-	error = NULL;
-	gtk_builder_add_from_file (gui,
-				   BUILDERDIR "/panel-run-dialog.ui",
-				   &error);
-
-        if (error) {
-		char *secondary;
-
-		secondary = g_strdup_printf (_("Unable to load file '%s': %s."),
-					     BUILDERDIR"/panel-run-dialog.ui",
-					     error->message);
-		panel_error_dialog (NULL, screen, "cannot_display_run_dialog",
-				    TRUE,
-				    _("Could not display run dialog"),
-				      secondary);
-		g_free (secondary);
-		g_error_free (error);
-		g_object_unref (gui);
-
-		return;
-	}
+	gtk_builder_add_from_resource (gui,
+	                               PANEL_RESOURCE_PATH "panel-run-dialog.ui",
+	                               NULL);
 
 	static_dialog = panel_run_dialog_new (screen, gui, activate_time);
 
