@@ -30,6 +30,7 @@
 #include <gtk/gtk.h>
 
 #include "panel-icon-names.h"
+#include "panel-schemas.h"
 
 static GtkIconSize panel_menu_icon_size = 0;
 static GtkIconSize panel_menu_bar_icon_size = 0;
@@ -93,10 +94,10 @@ typedef struct {
 } PanelStockItem;
 
 static PanelStockItem stock_items [] = {
-	{ PANEL_STOCK_EXECUTE,     GTK_STOCK_EXECUTE,       N_("_Run") },
-	{ PANEL_STOCK_FORCE_QUIT,  PANEL_STOCK_FORCE_QUIT,  N_("_Force quit") },
-	{ PANEL_STOCK_CLEAR,       GTK_STOCK_CLEAR,         N_("C_lear") },
-	{ PANEL_STOCK_DONT_DELETE, GTK_STOCK_CANCEL,        N_("D_on't Delete") }
+	{ PANEL_STOCK_EXECUTE,     "gtk-execute",          N_("_Run") },
+	{ PANEL_STOCK_FORCE_QUIT,  PANEL_STOCK_FORCE_QUIT, N_("_Force quit") },
+	{ PANEL_STOCK_CLEAR,       "gtk-clear",            N_("C_lear") },
+	{ PANEL_STOCK_DONT_DELETE, "gtk-cancel",           N_("D_on't Delete") }
 };
 
 static void
@@ -128,14 +129,33 @@ void
 panel_init_stock_icons_and_items (void)
 {
 	GtkIconFactory *factory;
+	GSettings      *settings;
+	gint		icon_size;
 
-	panel_menu_icon_size = gtk_icon_size_register ("panel-menu",
-						       PANEL_DEFAULT_MENU_ICON_SIZE,
-						       PANEL_DEFAULT_MENU_ICON_SIZE);
+	settings = g_settings_new (PANEL_MENU_BAR_SCHEMA);
 
-	panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar",
-							   PANEL_DEFAULT_MENU_BAR_ICON_SIZE,
-							   PANEL_DEFAULT_MENU_BAR_ICON_SIZE);
+	icon_size = g_settings_get_enum (settings, "item-icon-size");
+	if (icon_size <= 0) {
+		panel_menu_icon_size = gtk_icon_size_register ("panel-menu",
+							       PANEL_DEFAULT_MENU_ICON_SIZE,
+							       PANEL_DEFAULT_MENU_ICON_SIZE);
+	} else {
+		/* underscores to prevent themes from altering these settings */
+		panel_menu_icon_size = gtk_icon_size_register ("__panel-menu",
+							       icon_size,
+							       icon_size);
+	}
+
+	icon_size = g_settings_get_enum (settings, "icon-size");
+	if (icon_size <= 0) {
+		panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar",
+								   PANEL_DEFAULT_MENU_BAR_ICON_SIZE,
+								   PANEL_DEFAULT_MENU_BAR_ICON_SIZE);
+	} else {
+		panel_menu_bar_icon_size = gtk_icon_size_register ("__panel-foobar",
+								   icon_size,
+								   icon_size);
+	}
 
 	panel_add_to_icon_size = gtk_icon_size_register ("panel-add-to",
 							 PANEL_ADD_TO_DEFAULT_ICON_SIZE,
@@ -148,4 +168,5 @@ panel_init_stock_icons_and_items (void)
 	panel_init_stock_items (factory);
 
 	g_object_unref (factory);
+	g_object_unref (settings);
 }
