@@ -23,11 +23,15 @@
 #include <unistd.h>
 #include <sys/types.h>
 
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdkx.h>
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-desktop-utils.h>
@@ -39,7 +43,6 @@
 #include <libpanel-util/panel-xdg.h>
 
 #include "applet.h"
-#include "nothing.h"
 #include "xstuff.h"
 #include "panel-config-global.h"
 #include "panel-schemas.h"
@@ -48,6 +51,8 @@
 #include "panel-icon-names.h"
 #include "panel-lockdown.h"
 
+static Atom _net_active_window = None;
+
 char *
 panel_util_make_exec_uri_for_desktop (const char *exec)
 {
@@ -116,11 +121,7 @@ panel_push_window_busy (GtkWidget *window)
 			                                                GDK_WATCH);
 
 			gdk_window_set_cursor (win, cursor);
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_object_unref (cursor);
-#else
-			gdk_cursor_unref (cursor);
-#endif
 			gdk_flush ();
 		}
 	}
@@ -325,18 +326,14 @@ panel_find_icon (GtkIconTheme  *icon_theme,
 
 	if (info) {
 		retval = g_strdup (gtk_icon_info_get_filename (info));
-#if GTK_CHECK_VERSION (3, 8, 0)
 		g_object_unref (info);
-#else
-		gtk_icon_info_free (info);
-#endif
 	} else
 		retval = NULL;
 
 	return retval;
 }
 
-GdkPixbuf *
+cairo_surface_t *
 panel_load_icon (GtkIconTheme  *icon_theme,
 		 const char    *icon_name,
 		 int            size,
@@ -344,7 +341,8 @@ panel_load_icon (GtkIconTheme  *icon_theme,
 		 int            desired_height,
 		 char         **error_msg)
 {
-	GdkPixbuf *retval;
+	GdkPixbuf *pixbuf;
+	cairo_surface_t *surface;
 	char      *file;
 	GError    *error;
 
@@ -360,19 +358,25 @@ panel_load_icon (GtkIconTheme  *icon_theme,
 	}
 
 	error = NULL;
-	retval = gdk_pixbuf_new_from_file_at_size (file,
+	pixbuf = gdk_pixbuf_new_from_file_at_scale (file,
 						   desired_width,
 						   desired_height,
+						   TRUE,
 						   &error);
 	if (error) {
 		if (error_msg)
 			*error_msg = g_strdup (error->message);
 		g_error_free (error);
+		surface = NULL;
+	}
+	else {
+		surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, 0, NULL);
 	}
 
 	g_free (file);
+	g_object_unref (pixbuf);
 
-	return retval;
+	return surface;
 }
 
 static char* panel_lock_screen_action_get_command(const char* action)
@@ -769,20 +773,12 @@ panel_util_cairo_rgbdata_to_pixbuf (unsigned char *data,
 
 char *
 guess_icon_from_exec (GtkIconTheme *icon_theme,
-		      GKeyFile     *key_file)
+		      const gchar  *exec)
 {
-	char *exec;
 	char *icon_name;
 	char *path;
 
-	exec = panel_key_file_get_string (key_file, "Exec");
-	if (!exec || !exec [0]) {
-		g_free (exec);
-		return NULL;
-	}
-
 	icon_name = g_path_get_basename (exec);
-	g_free (exec);
 
 	path = panel_find_icon (icon_theme, icon_name, 48);
 	if (!path) {
@@ -1249,3 +1245,89 @@ panel_util_get_file_optional_homedir (const char *location)
 
 	return file;
 }
+
+static void panel_menu_bar_get_net_active_window(Display *xdisplay)
+{
+	if (_net_active_window == None)
+		_net_active_window = XInternAtom (xdisplay,
+						  "_NET_ACTIVE_WINDOW",
+						  False);
+}
+
+Window panel_util_get_current_active_window (GtkWidget *toplevel)
+{
+	GdkScreen  *screen;
+	GdkDisplay *display;
+	GdkWindow  *root;
+	Display    *xdisplay;
+	Window      xroot;
+
+	Window      res = None;
+
+	Atom           return_type;
+	int            return_format;
+	unsigned long  n;
+	unsigned long  bytes;
+	unsigned char *prop = NULL;
+
+	screen   = gtk_window_get_screen (GTK_WINDOW(toplevel));
+	display  = gdk_screen_get_display (screen);
+	root     = gdk_screen_get_root_window (screen);
+
+	xdisplay = GDK_DISPLAY_XDISPLAY (display);
+	xroot    = GDK_WINDOW_XID (root);
+
+	panel_menu_bar_get_net_active_window (xdisplay);
+	if (_net_active_window != None
+	    && XGetWindowProperty (xdisplay, xroot, _net_active_window, 0, 1,
+				   False, XA_WINDOW, &return_type, &return_format,
+				   &n, &bytes, &prop) == Success)
+	{
+		if ((return_type == XA_WINDOW) && (return_format == 32) &&
+		    (n == 1) && (prop)) {
+			res = *(Window *)prop;
+		}
+
+		if (prop)
+			XFree (prop);
+
+	}
+	return res;
+}
+
+void panel_util_set_current_active_window (GtkWidget *toplevel, Window window)
+{
+	GdkScreen  *screen;
+	GdkDisplay *display;
+	GdkWindow  *root;
+	Display    *xdisplay;
+	Window      xroot;
+	XEvent      xev;
+
+	screen   = gtk_window_get_screen (GTK_WINDOW(toplevel));
+	display  = gdk_screen_get_display (screen);
+	root     = gdk_screen_get_root_window (screen);
+
+	xdisplay = GDK_DISPLAY_XDISPLAY (display);
+	xroot    = GDK_WINDOW_XID (root);
+
+	panel_menu_bar_get_net_active_window (xdisplay);
+	if (_net_active_window == None)
+		return;
+
+	xev.xclient.type	 = ClientMessage;
+	xev.xclient.serial	 = 0;
+	xev.xclient.send_event	 = True;
+	xev.xclient.window	 = window;
+	xev.xclient.message_type = _net_active_window;
+	xev.xclient.format	 = 32;
+	xev.xclient.data.l[0]	 = 2; /* requestor type; we're not an app */
+	xev.xclient.data.l[1]	 = CurrentTime;
+	xev.xclient.data.l[2]	 = None; /* our currently active window */
+	xev.xclient.data.l[3]	 = 0;
+	xev.xclient.data.l[4]	 = 0;
+
+	XSendEvent (xdisplay, xroot, False,
+		    SubstructureRedirectMask | SubstructureNotifyMask,
+		    &xev);
+}
